@@ -7,13 +7,13 @@ USER_AGENT = "Mozilla/5.0"
 
 
 def get_html(*args, **kwargs):
-    """ Get HTML document from requests content. """
+    """ Gets HTML document from requests content. """
     content = get_request(*args, **kwargs).content
     return BeautifulSoup(content, "html.parser")
 
 
 def get_request(*args, max_retry=10, **kwargs):
-    """ Get requests.models.Response object using requests.get.
+    """ Gets requests.models.Response object using requests.get.
     Retry request if request fails, with number of iteration specified
     by max_retry. """
     kwargs.setdefault("headers", {}).setdefault("User-Agent", USER_AGENT)
@@ -27,9 +27,9 @@ def get_request(*args, max_retry=10, **kwargs):
 
             print("Request failed: (%s). Retrying after %s seconds ..." % (exc, "%.2f" % wait))
             time.sleep(wait)
-            # multiply wait time by 2 every iterative recursion
-            retries += 1
+            # double the wait time after every iteration
             wait *= 2
+            retries += 1
             return recurse_get_request(*args, retries=retries, wait=wait, **kwargs)
 
     return recurse_get_request(*args, **kwargs)
